@@ -4,7 +4,7 @@ use 5.10.0;
 use strict;
 use warnings;
 
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 use Exporter;
 our @EXPORT = qw< path file >;
@@ -55,7 +55,8 @@ sub child { path(shift->[0], @_) }
 
 
 # essentially just reblessings
-sub parent	{ path( &Path::Tiny::parent ) }
+sub parent		{ path( &Path::Tiny::parent   ) }
+sub realpath	{ path( &Path::Tiny::realpath ) }
 
 # simple correspondences
 *dir		=	\&parent;
@@ -171,7 +172,7 @@ Path::Class::Tiny - a Path::Tiny wrapper for Path::Class compatibility
 
 =head1 VERSION
 
-This document describes version 0.02 of Path::Class::Tiny.
+This document describes version 0.03 of Path::Class::Tiny.
 
 =head1 SYNOPSIS
 
@@ -272,6 +273,45 @@ me know.
 The POD is somewhat impoverished at the moment.  Hopefully that will improve over time.  Again,
 patches welcomed.
 
+=head1 PATH::CLASS STYLE METHODS
+
+=head2 cleanup
+
+Redirects to L<Path::Tiny/canonpath>.
+
+=head2 components
+
+Basically just like C<components> from L<Path::Class::Dir>, which means that it accepts offset and
+length arguments (which L<Path::Class::File> doesn't).  Another nice difference: calling
+C<components> from Path::Class::File in scalar context doesn't do anything useful, whereas
+Path::Class::Tiny always returns the number of components, which is (hopefully) what you expect.
+
+The only real difference between Path::Class::Tiny's C<components> and Path::Class::Dir's
+C<components> is that you don't get the volume returned in the Path::Class::Dir version.  In this
+version, the volume (if any) will just be part of the first component in the list.
+
+=head2 dir_list
+
+Just an alias for L</components>, so it also works on files (L<Path::Class::File> doesn't have a
+C<dir_list> method).  This means the basename is always the last entity in the list, even for files.
+Basically this is just here for compatibility's sake, and you probably shouldn't use it for new
+code, because the name doesn't really sound like what it does.
+
+=head2 next
+
+Uses L<Path::Tiny/iterator> (with its default value of no recursion) to implement the interface of
+C<next> from L<Path::Class::Dir>.  The primary difference this engenders is that the
+Path::Class::Dir version I<will> return C<.> and C<..>, whereas this version will I<not>.  I also
+don't guarantee this version is re-entrant.
+
+=head2 rmtree
+
+Just an alias to L<Path::Tiny/remove_tree>.
+
+=head2 subdir
+
+Just an alias to L<Path::Tiny/child>.
+
 =head1 NEW METHODS
 
 =head2 ef
@@ -308,12 +348,12 @@ You can find documentation for this module with the perldoc command.
 
 =head2 Bugs / Feature Requests
 
-		This module is on GitHub.  Feel free to fork and submit patches.  Please note that I develop
-		via TDD (Test-Driven Development), so a patch that includes a failing test is much more
-		likely to get accepted (or least likely to get accepted more quickly).
+This module is on GitHub.  Feel free to fork and submit patches.  Please note that I develop
+via TDD (Test-Driven Development), so a patch that includes a failing test is much more
+likely to get accepted (or at least likely to get accepted more quickly).
 
-		If you just want to report a problem or suggest a feature, that's okay too.  You can create
-		an issue on GitHub here: L<http://github.com/barefootcoder/path-class-tiny/issues>.
+If you just want to report a problem or suggest a feature, that's okay too.  You can create
+an issue on GitHub here: L<http://github.com/barefootcoder/path-class-tiny/issues>.
 
 =head2 Source Code
 
